module.exports = cacheObjToCss;

/*
 * Converts cache object to a CSS string
 * @param  {object} cacheObj Cache object
 * @return {string}          String of CSS
 */
function cacheObjToCss(cacheObj) {
  var mediaCss = '';
  var css = '';
  for (var key in cacheObj) {
    if (key === 'media') {
      mediaCss += mediaObjToCss(cacheObj[key]);
      continue;
    }
    css += baseHandler(key, cacheObj[key]);
  }
  return css + mediaCss;
}

function mediaObjToCss(mediaObj) {
  var css = '';
  for (var query in mediaObj) {
    var obj = mediaObj[query];
    var mediaCss = '';
    for (var key in obj) {
      mediaCss += baseHandler(key, obj[key]);
    }
    css += "@media " + query + "{" + mediaCss + "}";
  }
  return css;
}

function baseHandler(key, valueObj) {
  return key === 'pseudo' ?
    pseudoObjToCss(valueObj) : valsObjToCss(key, valueObj);
}

function pseudoObjToCss(pseudoObj) {
  var css = '';
  for (var pseudoClass in pseudoObj) {
    var propsObj = pseudoObj[pseudoClass];
    for (var prop in propsObj) {
      css += valsObjToCss(prop, propsObj[prop], pseudoClass);
    }
  }
  return css;
}

function valsObjToCss(prop, valsObj, pseudo) {
  var css = '';
  for (var val in valsObj) {
    var className = valsObj[val];
    css += declToCss(prop, val, className, pseudo);
  }
  return css;
}

function declToCss(prop, val, className, pseudo) {
  var classString = pseudo ? ("" + className + pseudo) : className;
  return ("." + classString + "{" + prop + ":" + val + "}");
}
